/*
	Created by:		Esposito Vittorio
	GitHub:			https://github.com/VittorioEsposito	
	
	J1850-PWM-Encoding-Library
	
	Arduino library which allows to communicate on J1850-PWM mode. 
	It works with both wire and radio transmissions. 
	You just have to choose your bit-rate (lower is better). 
	It doesn't have either a header nor a parity check. 
	These functions could be implemented at a higher protocol layer. 
	This library has been tested also with FSK module RTX-mid-868.
	
*/

#include <Arduino.h>
#include "avr/interrupt.h"

#define DEFAULT_RX_PIN 		3
#define BUFFER_SIZE			64

class PwmDecoder 
{
	static volatile bool flagDecoder;
	
	private:
		uint8_t  _RX_PIN;
		char _RX_BUFFER[BUFFER_SIZE];
		uint16_t _BUFFER_INDEX = 0;
		int _count = 7;
		unsigned long _timeOld;	
		uint16_t timeOut = 100;		// mS	
		char c = 0x00;
		bool _high_speed = false;
		bool _logic = true;		// 1: Direct; 0: Inverse
	
	public:
		PwmDecoder(uint8_t RX_PIN);
		void setRxPin(uint8_t RX_PIN);
		uint8_t getRxPin();
		void setLogic(bool logic);
		void begin(uint32_t BR);
		
		static void isrPwmDecoder();
		void receive();
		bool isReceiving();					//
		bool available();
		String readString();
		
		uint32_t BITRATE;
		uint32_t BIT_TIME;
		uint32_t HALF_BIT_TIME;
		
};

